@@ -904,10 +904,19 @@ class VE(RegistroDecomp):
         linha = (f"{VE.mnemonico}".ljust(4) +
                  f"{self._dados[0]}".rjust(3) + "  ")
         for i in range(1, len(self._dados)):
-            linha += f"{round(self._dados[i], 2)}"
+            linha += f"{round(self._dados[i], 2)}".rjust(5)
         linha += "\n"
         arq.write(linha)
 
+    @property
+    def codigo(self) -> int:
+        """
+        O código do posto associado ao volume
+
+        :return: O código como `int`.
+        """
+        return self._dados[0]
+
 
 class RE(RegistroDecomp):
     """
